@@ -16,7 +16,10 @@
         totVar <- data.frame(Role = c("Predictor", "Response"),
                              "Variance" = totVar,
                              check.names = FALSE, stringsAsFactors = FALSE)
-        rownames(totVar) <- unlist(x$nam.dat, use.names = FALSE)
+        ## x$totVar stored as Xblock (covariates), Yblock (response)
+        ## so extract the names as covariate and response.
+        ## actually stored in the other order x$nam.dat[1L] == response
+        rownames(totVar) <- c(x$nam.dat$namX, x$nam.dat$namY)
         print(totVar, digits = digits, ...)
     }
     invisible(x)
