@@ -2,6 +2,6 @@
 function(object, axes = c(1:min(6, object$n.axes)), ...)
   {
     class(object) <- "summary.crossval"
-    return(object)
+    object
   }
 
